<?php
/**
 * Plugin Name: WooCommerce Account Pages by Iconic
 * Plugin URI: https://iconicwp.com/products/woocommerce-account-pages/
 * Description: Add and manage pages in your WooCommerce "My Account" area.
 * Version: 1.0.5
 * Author: Iconic <info@iconicwp.com>
 * Author URI: https://iconicwp.com
 * Text Domain: iconic-wap
 * WC requires at least: 2.6.14
 * WC tested up to: 3.5.5
 */

if ( ! defined( 'WPINC' ) ) {
	wp_die();
}

class Iconic_Woo_Account_Pages {
	/**
	 * Plugin version.
	 *
	 * @var string
	 */
	public static $version = "1.0.5";

	/**
	 * Class prefix
	 *
	 * @since  1.0.0
	 * @access protected
	 * @var string $class_prefix
	 */
	protected $class_prefix = "Iconic_WAP_";

	/**
	 * Construct
	 */
	public function __construct() {
		$this->textdomain();
		$this->define_constants();
		$this->load_classes();

		if ( ! Iconic_WAP_Core_Helpers::is_plugin_active( 'woocommerce/woocommerce.php' ) ) {
			return;
		}

		add_action( 'init', array( 'Iconic_WAP_Pages', 'initiate' ), 10, 1 );
		add_action( 'save_post', array( 'Iconic_WAP_Helpers', 'maybe_refresh_permalinks' ), 10, 1 );
	}

	/**
	 * Load textdomain
	 */
	public function textdomain() {
		load_plugin_textdomain( 'iconic-wap', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
	}

	/**
	 * Set constants
	 */
	public function define_constants() {
		$this->define( 'ICONIC_WAP_PATH', plugin_dir_path( __FILE__ ) );
		$this->define( 'ICONIC_WAP_URL', plugin_dir_url( __FILE__ ) );
		$this->define( 'ICONIC_WAP_INC_PATH', ICONIC_WAP_PATH . 'inc/' );
		$this->define( 'ICONIC_WAP_VENDOR_PATH', ICONIC_WAP_INC_PATH . 'vendor/' );
		$this->define( 'ICONIC_WAP_BASENAME', plugin_basename( __FILE__ ) );
	}

	/**
	 * Define constant if not already set.
	 *
	 * @param string      $name
	 * @param string|bool $value
	 */
	private function define( $name, $value ) {
		if ( ! defined( $name ) ) {
			define( $name, $value );
		}
	}

	/**
	 * Load classes
	 */
	private function load_classes() {
		require_once( ICONIC_WAP_INC_PATH . 'class-core-autoloader.php' );

		Iconic_WAP_Core_Autoloader::run( array(
			'prefix'   => 'Iconic_WAP_',
			'inc_path' => ICONIC_WAP_INC_PATH,
		) );

		Iconic_WAP_Core_Settings::run( array(
			'vendor_path'   => ICONIC_WAP_VENDOR_PATH,
			'title'         => 'WooCommerce Account Pages',
			'version'       => self::$version,
			'menu_title'    => 'Account Pages',
			'settings_path' => ICONIC_WAP_INC_PATH . 'admin/settings.php',
			'option_group'  => 'iconic_wap',
			'docs'          => array(
				'collection'      => '/collection/101-woocommerce-account-pages',
				'troubleshooting' => '/category/106-troubleshooting',
				'getting-started' => '/category/104-getting-started',
			),
			'cross_sells'   => array(
				'iconic-woo-show-single-variations',
				'iconic-woothumbs',
			),
		) );
	}
}

$iconic_wap = new Iconic_Woo_Account_Pages();